@@ -1,5 +1,5 @@
 package List::Compare::Functional;
-$VERSION = 0.40;
+$VERSION = 0.41;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw|
     get_intersection
@@ -136,9 +136,15 @@ sub get_intersection_ref {
 
 sub _intersection_engine {
     my $seenrefsref = _calc_seen1(@_);
-    my $xintersectionref = _calculate_xintersection_only($seenrefsref);
-    my $intersectionref = _calculate_hash_intersection($xintersectionref);
-    return [ keys %{$intersectionref} ];
+    my @vals = sort { scalar(keys(%{$a})) <=> scalar(keys(%{$b})) }
+        @{$seenrefsref};
+    my %intersection = map { $_ => 1 } keys %{$vals[0]};
+    for my $l ( 1..$#vals ) {
+        %intersection = map { $_ => 1 }
+            grep { exists $intersection{$_} }
+            keys %{$vals[$l]};
+    }
+    return [ keys %intersection ];
 }
 
 sub get_unique {
@@ -520,8 +526,8 @@ List::Compare::Functional - Compare elements of two or more lists
 
 =head1 VERSION
 
-This document refers to version 0.40 of List::Compare::Functional.
-This version was released February 07 2015.  The first released
+This document refers to version 0.41 of List::Compare::Functional.
+This version was released February 08 2015.  The first released
 version of List::Compare::Functional was v0.21.  Its version numbers
 are set to be consistent with the other parts of the List::Compare
 distribution.
@@ -1685,7 +1691,7 @@ James E. Keenan (jkeenan@cpan.org).  When sending correspondence, please
 include 'List::Compare::Functional' or 'List-Compare-Functional' in your
 subject line.
 
-Creation date:  May 20, 2002.  Last modification date:  February 07 2015.
+Creation date:  May 20, 2002.  Last modification date:  February 08 2015.
 Copyright (c) 2002-15 James E. Keenan.  United States.  All rights reserved.
 This is free software and may be distributed under the same terms as Perl
 itself.
